==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/EgressRouterStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EgressRouterStatusBuilder extends EgressRouterStatusFluentImpl<EgressRouterStatusBuilder> implements VisitableBuilder<EgressRouterStatus,EgressRouterStatusBuilder>{
  public EgressRouterStatusBuilder() {
    this(false);
  }
  public EgressRouterStatusBuilder(Boolean validationEnabled) {
    this(new EgressRouterStatus(), validationEnabled);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EgressRouterStatus(), validationEnabled);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,EgressRouterStatus instance) {
    this(fluent, instance, false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,EgressRouterStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EgressRouterStatusBuilder(EgressRouterStatus instance) {
    this(instance,false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EgressRouterStatusFluent<?> fluent;
  Boolean validationEnabled;
  public EgressRouterStatus build() {
    EgressRouterStatus buildable = new EgressRouterStatus(fluent.getConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/EgressRouterStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EgressRouterStatusBuilder extends EgressRouterStatusFluent<EgressRouterStatusBuilder> implements VisitableBuilder<EgressRouterStatus,EgressRouterStatusBuilder>{
  public EgressRouterStatusBuilder() {
    this(false);
  }
  public EgressRouterStatusBuilder(Boolean validationEnabled) {
    this(new EgressRouterStatus(), validationEnabled);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EgressRouterStatus(), validationEnabled);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,EgressRouterStatus instance) {
    this(fluent, instance, false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatusFluent<?> fluent,EgressRouterStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EgressRouterStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withConditions(instance.getConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EgressRouterStatusBuilder(EgressRouterStatus instance) {
    this(instance,false);
  }
  public EgressRouterStatusBuilder(EgressRouterStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EgressRouterStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withConditions(instance.getConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EgressRouterStatusFluent<?> fluent;
  Boolean validationEnabled;
  public EgressRouterStatus build() {
    EgressRouterStatus buildable = new EgressRouterStatus(fluent.buildConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
